@@ -18,7 +18,8 @@ class Config:
     def is_enabled(self):
         return (
             self._config.getoption('random_order_enabled') or
-            self._config.getoption('random_order_num') > -1 or
+            (self._config.getoption('random_order_num') and 
+            self._config.getoption('random_order_num') > -1) or
             any(
                 not self._config.getoption(name).startswith('default:')
                 for name in ('random_order_bucket', 'random_order_seed')
