@@ -83,6 +83,8 @@ def pytest_collection_modifyitems(session, config, items):
                 session=session,
                 num=num
             )
+        print('plugin len(items): -------------')
+        print(len(items))
 
     except Exception as e:
         # See the finally block -- we only fail if we have lost user's tests.
